@@ -1,7 +1,7 @@
 /* screen-review.c
  *
- * Copyright 2001, 2002 Sun Microsystems, Inc.,
- * Copyright 2001, 2002 BAUM Retec, A.G.
+ * Copyright 2001 - 2005 Sun Microsystems, Inc.,
+ * Copyright 2001 - 2005 BAUM Retec, A.G.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -2318,8 +2318,8 @@ srw_elements_from_accessible (Accessible 	*accessible,
 					{
 					    cnt = strlen (text_chunk->string);   
 					    for (i = 0; i < cnt; i++)
-						if ((guint16)*(text_chunk->string + i) != 0x20 &&
-					    	    (guint16)*(text_chunk->string + i) != 0x160)   
+						if (text_chunk->string[i] != 0x20 &&
+					    	    (text_chunk->string[i] != 0x01 && text_chunk->string[i+1] != 0x60))
 						{
 						    only_spaces = FALSE;
 						    break;
